@@ -109,11 +109,19 @@ class Logger:
             InvalidLogLevelError: If the provided log levels are not supported.
         """
 
+        if min_loglevel in LogLevel:
+            self.min_loglevel: LogLevel = min_loglevel
+
+        else:
+            self.min_loglevel: LogLevel = LogLevel.INFO
+
+        if max_loglevel in LogLevel:
+            self.max_loglevel: LogLevel = max_loglevel
+
+        else:
+            self.max_loglevel: LogLevel = LogLevel.CRITICAL
+
         self.name: str = name
-        self.min_loglevel: LogLevel = min_loglevel \
-            if min_loglevel in LogLevel else LogLevel.INFO
-        self.max_loglevel: LogLevel = max_loglevel \
-            if max_loglevel in LogLevel else LogLevel.CRITICAL
 
         self.handlers: list[Handler] = []
 
